@@ -913,11 +913,11 @@ class Database:
                        end_date_str
 
             response = requests.get(link_str)
+
             response_ok = response_check(response)
             if response_ok == True:
 
                 result = json.loads(json.loads(response.content).replace("'", "\""))
-
                 df_list = []
                 for item in result:
                     date_int = item['_id']
@@ -1418,11 +1418,13 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
+
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),'%Y%m%d').date() >= \
                                    datetime.datetime.strptime(str(start_date), '%Y%m%d').date()
@@ -1437,7 +1439,7 @@ class Database:
                            'start_date_future': start_date_future,
                            'end_date_is_int': end_date_is_int,
                            'end_date_length': end_date_length,
-                           'end_date_future': end_date_future,
+                           #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
         
         return check_bool_dict
@@ -1469,11 +1471,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1488,7 +1490,7 @@ class Database:
                            'start_date_future': start_date_future,
                            'end_date_is_int': end_date_is_int,
                            'end_date_length': end_date_length,
-                           'end_date_future': end_date_future,
+                           #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
         
         return check_bool_dict
@@ -1523,11 +1525,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1555,7 +1557,7 @@ class Database:
                            'start_date_future': start_date_future,
                            'end_date_is_int': end_date_is_int,
                            'end_date_length': end_date_length,
-                           'end_date_future': end_date_future,
+                           #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date,
                            'rolling_day_int': rolling_day_int,
                            'rolling_day_length': rolling_day_length,
@@ -1589,11 +1591,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1607,7 +1609,7 @@ class Database:
                            'start_date_future': start_date_future,
                            'end_date_is_int': end_date_is_int,
                            'end_date_length': end_date_length,
-                           'end_date_future': end_date_future,
+                           #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
         return check_bool_dict
 
@@ -1633,11 +1635,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1651,7 +1653,7 @@ class Database:
             'start_date_future': start_date_future,
             'end_date_is_int': end_date_is_int,
             'end_date_length': end_date_length,
-            'end_date_future': end_date_future,
+            #'end_date_future': end_date_future,
             'end_after_start_date': end_after_start_date}
         
         return check_bool_dict
@@ -1682,10 +1684,10 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date), '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date), '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date), '%Y%m%d').date() >= datetime.datetime.strptime(
                 str(start_date), '%Y%m%d').date()
@@ -1699,7 +1701,7 @@ class Database:
                            'start_date_future': start_date_future,
                            'end_date_is_int': end_date_is_int,
                            'end_date_length': end_date_length,
-                           'end_date_future': end_date_future,
+                           #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date}
         return check_bool_dict
     
@@ -1734,11 +1736,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1755,7 +1757,7 @@ class Database:
             'start_date_future': start_date_future,
             'end_date_is_int': end_date_is_int,
             'end_date_length': end_date_length,
-            'end_date_future': end_date_future,
+            #'end_date_future': end_date_future,
             'end_after_start_date': end_after_start_date}
         
         return check_bool_dict
@@ -1791,11 +1793,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1812,7 +1814,7 @@ class Database:
             'start_date_future': start_date_future,
             'end_date_is_int': end_date_is_int,
             'end_date_length': end_date_length,
-            'end_date_future': end_date_future,
+            #'end_date_future': end_date_future,
             'end_after_start_date': end_after_start_date}
 
         return check_bool_dict
@@ -1858,11 +1860,11 @@ class Database:
             end_date_length = len(str(end_date)) == 8
         except:
             end_date_length = False
-        try:
-            end_date_future = datetime.datetime.strptime(str(end_date),
-                                                         '%Y%m%d').date() <= datetime.datetime.now().date()
-        except:
-            end_date_future = False
+        # try:
+        #     end_date_future = datetime.datetime.strptime(str(end_date),
+        #                                                  '%Y%m%d').date() <= datetime.datetime.now().date()
+        # except:
+        #     end_date_future = False
         try:
             end_after_start_date = datetime.datetime.strptime(str(end_date),
                                                               '%Y%m%d').date() >= datetime.datetime.strptime(
@@ -1877,7 +1879,7 @@ class Database:
                            'start_date_future': start_date_future,
                            'end_date_is_int': end_date_is_int,
                            'end_date_length': end_date_length,
-                           'end_date_future': end_date_future,
+                           #'end_date_future': end_date_future,
                            'end_after_start_date': end_after_start_date,
                            'deri_type': deri_type,
                            'exp_type': exp_type}
